unit help;

interface

uses Windows, SysUtils, Classes, Graphics, Forms, Controls, StdCtrls, 
  Buttons, ExtCtrls, ComCtrls, Menus, Dialogs;

type
  THelpDialog = class(TForm)
    OKBtn: TButton;
    RTF1: TRichEdit;
    PopupMenu1: TPopupMenu;
    Edit1: TMenuItem;
    N1: TMenuItem;
    New1: TMenuItem;
    Open1: TMenuItem;
    Save1: TMenuItem;
    SaveAs1: TMenuItem;
    N2: TMenuItem;
    Copy1: TMenuItem;
    Cut1: TMenuItem;
    Paste1: TMenuItem;
    SelectAll1: TMenuItem;
    Delete1: TMenuItem;
    Font1: TMenuItem;
    OpenDialog1: TOpenDialog;
    SaveDialog1: TSaveDialog;
    FontDialog1: TFontDialog;
    procedure FormCreate(Sender: TObject);
    procedure OKBtnClick(Sender: TObject);
    procedure Edit1Click(Sender: TObject);
    procedure New1Click(Sender: TObject);
    procedure Open1Click(Sender: TObject);
    procedure Save1Click(Sender: TObject);
    procedure SaveAs1Click(Sender: TObject);
    procedure Copy1Click(Sender: TObject);
    procedure Cut1Click(Sender: TObject);
    procedure Paste1Click(Sender: TObject);
    procedure Delete1Click(Sender: TObject);
    procedure SelectAll1Click(Sender: TObject);
    procedure Font1Click(Sender: TObject);
  private
    fFilename:      string;
    fSelFont:       TFont;
  public

  end;

var
  HelpDialog: THelpDialog;

{ ---------------------------------------------------------------------------- }
{ ---------------------------------------------------------------------------- }

implementation

{$R *.DFM}

{ ---------------------------------------------------------------------------- }

procedure THelpDialog.FormCreate(Sender: TObject);
var
    i,n:    integer;
    s:      string;
begin
Left   := (Screen.Width  - Width)  div 2;
Top    := (Screen.Height - Height) div 2;

s := ExtractFilePath(application.ExeName) + 'PX4Help.rtf';
s := LowerCase(s);
if (FileExists(s)) then
    begin
    fFilename := s;
    RTF1.Lines.LoadFromFile(fFilename);
    Caption := fFilename;
    end;

RTF1.ReadOnly := true;
Edit1.Enabled := true;
Edit1.Checked := false;
RTF1.ReadOnly      := (not Edit1.Checked);
New1.Enabled       := Edit1.Checked;
Open1.Enabled      := Edit1.Checked;
Save1.Enabled      := Edit1.Checked;
SaveAs1.Enabled    := Edit1.Checked;
Copy1.Enabled      := Edit1.Checked;
Cut1.Enabled       := Edit1.Checked;
Paste1.Enabled     := Edit1.Checked;
SelectAll1.Enabled := Edit1.Checked;
Delete1.Enabled    := Edit1.Checked;
Font1.Enabled      := Edit1.Checked;

fSelFont := TFont.Create;
end;

{ ---------------------------------------------------------------------------- }

procedure THelpDialog.OKBtnClick(Sender: TObject);
begin
Visible := false;
end;

{ ---------------------------------------------------------------------------- }

procedure THelpDialog.Edit1Click(Sender: TObject);
begin
Edit1.Checked := (not Edit1.Checked);
RTF1.ReadOnly      := (not Edit1.Checked);
New1.Enabled       := Edit1.Checked;
Open1.Enabled      := Edit1.Checked;
Save1.Enabled      := Edit1.Checked;
SaveAs1.Enabled    := Edit1.Checked;
Copy1.Enabled      := Edit1.Checked;
Cut1.Enabled       := Edit1.Checked;
Paste1.Enabled     := Edit1.Checked;
SelectAll1.Enabled := Edit1.Checked;
Delete1.Enabled    := Edit1.Checked;
Font1.Enabled      := Edit1.Checked;
end;

{ ---------------------------------------------------------------------------- }

procedure THelpDialog.New1Click(Sender: TObject);
begin
RTF1.Clear;
fFilename := '';
Caption := '<new file>';
end;

{ ---------------------------------------------------------------------------- }

procedure THelpDialog.Open1Click(Sender: TObject);
begin
if (OpenDialog1.Execute) then
    begin
    fFilename := OpenDialog1.Filename;
    RTF1.Clear;
    RTF1.Lines.LoadFromFile(fFilename);
    Caption := fFilename;
    end;
end;

{ ---------------------------------------------------------------------------- }

procedure THelpDialog.Save1Click(Sender: TObject);
begin
if (length(fFilename) > 0) then RTF1.Lines.SaveToFile(fFilename)
else                            SaveAs1Click(Sender);
end;

{ ---------------------------------------------------------------------------- }

procedure THelpDialog.SaveAs1Click(Sender: TObject);
begin
if (SaveDialog1.Execute) then
    begin
    fFilename := SaveDialog1.Filename;
    RTF1.Lines.SaveToFile(fFilename);
    Caption := fFilename;
    end;
end;

{ ---------------------------------------------------------------------------- }

procedure THelpDialog.Copy1Click(Sender: TObject);
begin
if (RTF1.SelLength > 0) then RTF1.CopyToClipboard;
end;

{ ---------------------------------------------------------------------------- }

procedure THelpDialog.Cut1Click(Sender: TObject);
begin
if (RTF1.SelLength > 0) then RTF1.CutToClipboard;
end;

{ ---------------------------------------------------------------------------- }

procedure THelpDialog.Paste1Click(Sender: TObject);
begin
RTF1.PasteFromClipboard;
end;

{ ---------------------------------------------------------------------------- }

procedure THelpDialog.Delete1Click(Sender: TObject);
begin
if (RTF1.SelLength > 0) then RTF1.ClearSelection;
end;

{ ---------------------------------------------------------------------------- }

procedure THelpDialog.SelectAll1Click(Sender: TObject);
begin
RTF1.SelectAll;
end;

{ ---------------------------------------------------------------------------- }

procedure THelpDialog.Font1Click(Sender: TObject);
begin
fSelFont.Name  := RTF1.SelAttributes.Name;
fSelFont.Color := RTF1.SelAttributes.Color;
fSelFont.Size  := RTF1.SelAttributes.Size;
fSelFont.Pitch := RTF1.SelAttributes.Pitch;
FontDialog1.Font := fSelFont;

if (RTF1.SelLength > 0) then
if (FontDialog1.Execute) then
    begin
    RTF1.SelAttributes.Assign(FontDialog1.Font);
    end;
end;

end.
